"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("mz/fs");
const path = require("path");
async function traversePath(base, func) {
    const files = await fs_1.readdir(base);
    for (const file of files) {
        const fullName = path.join(base, file);
        const fileStat = await fs_1.stat(fullName);
        if (fileStat.isFile()) {
            func(fullName);
        }
        else if (fileStat.isDirectory()) {
            await traversePath(fullName, func);
        }
    }
}
exports.traversePath = traversePath;
async function generateFileList(baseDir) {
    let normalizedBase = path.normalize(baseDir);
    if (normalizedBase.charAt(normalizedBase.length - 1) !== path.sep) {
        normalizedBase += path.sep;
    }
    const fileList = {
        baseDir: normalizedBase,
        files: []
    };
    await traversePath(normalizedBase, (file) => {
        const final = path.relative(normalizedBase, file);
        fileList.files.push(final);
    });
    return fileList;
}
exports.generateFileList = generateFileList;
function generateFileListDiff(left, right) {
    return {
        baseDir: {
            left: left.baseDir,
            right: right.baseDir,
        },
        leftOnly: left.files.filter((file) => !right.files.includes(file)),
        rightOnly: right.files.filter((file) => !left.files.includes(file)),
        all: left.files.filter((file) => right.files.includes(file)),
    };
}
exports.generateFileListDiff = generateFileListDiff;
//# sourceMappingURL=fileList.js.map